@@ -1,8 +1,5 @@
 package Slovo::Model::Users;
 use Mojo::Base 'Slovo::Model', -signatures;
-use feature qw(lexical_subs unicode_strings);
-## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
-no warnings "experimental::lexical_subs";
 
 my $table    = 'users';
 my $ug_table = 'user_group';
